@@ -19,27 +19,20 @@ Modules:
     agents
     catalog
     datasets
-    dimensionality
-    distributions
-    generator
     keras
-    models
-    preprocess
+    mplot
+    tfp
     trials
     utils
-    visualize
 """
 
 import psiz.agents
 import psiz.catalog
 import psiz.datasets
-import psiz.dimensionality
-import psiz.distributions
-import psiz.generators
 import psiz.keras
-import psiz.models
-import psiz.preprocess
-import psiz.restart
+import psiz.mplot
+import psiz.tfp
 import psiz.trials
 import psiz.utils
-import psiz.visualize
+
+psiz.models = psiz.keras.models  # TEMPORARY For backwards compatability.
